@@ -75,6 +75,10 @@ def main(args=sys.argv[1:]):
     except ValueError:
         pass
 
+    tags = None
+    if options.tags:
+        tags = [tag.strip('@') for tag in options.tags]
+
     runner = lettuce.Runner(
         base_path,
         scenarios=options.scenarios,
@@ -82,7 +86,7 @@ def main(args=sys.argv[1:]):
         random=options.random,
         enable_xunit=options.enable_xunit,
         xunit_filename=options.xunit_file,
-        tags=options.tags,
+        tags=tags,
     )
 
     result = runner.run()
