@@ -730,7 +730,7 @@ class Scenario(object):
     def _find_tags_in(self, original_string):
         broad_regex = re.compile(ur"([@].*)%s: (%s)" % (
             self.language.scenario_separator,
-            self.name), re.DOTALL)
+            re.escape(self.name)), re.DOTALL)
 
         regexes = []
         if not self.previous_scenario:
@@ -739,9 +739,9 @@ class Scenario(object):
         else:
             regexes.append(re.compile(ur"(?:%s: %s.*)([@]?.*)%s: (%s)\s*\n" % (
                 self.language.non_capturable_scenario_separator,
-                self.previous_scenario.name,
+                re.escape(self.previous_scenario.name),
                 self.language.scenario_separator,
-                self.name), re.DOTALL))
+                re.escape(self.name)), re.DOTALL))
 
         def try_finding_with(regex):
             found = regex.search(original_string)
@@ -952,6 +952,11 @@ class Feature(object):
                                                     language)
             self._set_definition(feature_definition)
 
+        if original_string and '@' in self.original_string:
+            self.tags = self._find_tags_in(original_string)
+        else:
+            self.tags = None
+
         self._add_myself_to_scenarios()
 
     @property
@@ -978,6 +983,35 @@ class Feature(object):
     def _add_myself_to_scenarios(self):
         for scenario in self.scenarios:
             scenario.feature = self
+            if scenario.tags and self.tags:
+                scenario.tags.extend(self.tags)
+
+    def _find_tags_in(self, original_string):
+        broad_regex = re.compile(ur"([@].*)%s: (%s)" % (
+            self.language.feature,
+            re.escape(self.name)), re.DOTALL)
+
+        regexes = [broad_regex]
+
+        def try_finding_with(regex):
+            found = regex.search(original_string)
+
+            if found:
+                tag_lines = found.group().splitlines()
+                tags = set(chain(*map(self._extract_tag, tag_lines)))
+                return tags
+
+        for regex in regexes:
+            found = try_finding_with(regex)
+            if found:
+                return found
+
+        return []
+
+    def _extract_tag(self, item):
+        regex = re.compile(r'(?:(?:^|\s+)[@]([^@\s]+))')
+        found = regex.findall(item)
+        return found
 
     def __repr__(self):
         return u'<%s: "%s">' % (self.language.first_of_feature, self.name)
@@ -1072,7 +1106,6 @@ class Feature(object):
 
     def _check_scenario_syntax(self, lines, filename):
         empty_scenario = ('%s:' % (self.language.first_of_scenario)).lower()
-
         for line in lines:
             if line.lower() == empty_scenario:
                 raise LettuceSyntaxError(
@@ -1099,6 +1132,13 @@ class Feature(object):
         background = None
 
         if not re.search("^" + scenario_prefix, joined):
+            if not parts:
+                raise LettuceSyntaxError(
+                    with_file,
+                    (u"Features must have scenarios.\n"
+                     "Please refer to the documentation available at http://lettuce.it for more information.")
+                )
+
             description, background_lines = self._extract_desc_and_bg(parts[0])
 
             background = background_lines and Background.from_string(
